@@ -13,7 +13,7 @@ Token = namedtuple('Token', ['type', 'value'])
 
 SPECIALS = '(),='
 COMMENT_PATTERN = re.compile(r'^/\*(.+)\*/')
-VALUE_PATTERN = re.compile(fr'^(?:([\"\'])((?:\\?[^\n])+?)\1|([^{SPECIALS}\s]+))')
+VALUE_PATTERN = re.compile(fr'^(?:([\"\'])((?:\\?[^\n])+?)\1|([^{SPECIALS}\n]+))')
 
 
 
